@@ -1,5 +1,5 @@
 class TestEvent:
-    def test_event(self, consul_obj):
+    def test_event(self, consul_obj) -> None:
         c, _consul_version = consul_obj
 
         assert c.event.fire("fooname", "foobody")
@@ -7,7 +7,7 @@ class TestEvent:
         assert [x["Name"] == "fooname" for x in events]
         assert [x["Payload"] == "foobody" for x in events]
 
-    def test_event_targeted(self, consul_obj):
+    def test_event_targeted(self, consul_obj) -> None:
         c, _consul_version = consul_obj
 
         assert c.event.fire("fooname", "foobody")
